@@ -24,6 +24,7 @@ class GoogleEvent(dict):
         self['published'] = None
         self['status'] = None
         self['raw'] = None
+        self['single_event'] = True
 
     def dump(self):
         printd("The Google event :")
@@ -35,6 +36,7 @@ class GoogleEvent(dict):
         printd("location : " + str(self['location']))
         printd("modified : " + str(self['updated']))
         printd("recurrence : " + str(self['recurrence']))
+        printd("Recurring : " + str(self['single_event']))
 
         printd("The GPE event :")
         printd("eventid : " + str(self.eventid()))
@@ -89,6 +91,7 @@ class GoogleEvent(dict):
         "Return the GPE start date of the Google event"
         print("google_event : start_date : entering")
         if self['recurrence']:
+            self['single_event'] = False
             #It's a recurrent event
             #I get the start date in the rstring
             print("google_event : start_date : It s a recurring event")
@@ -106,6 +109,7 @@ class GoogleEvent(dict):
             #It's a single event
             #I get the start date in usualy field
             print("google_event : start_date : It s a single event")
+            self['single_event'] = True
             start_date = string.replace(self['start_date'], "T", " ")
             start_date = start_date[0:19]
             
