@@ -12,6 +12,7 @@ import string, time, datetime
 import erminigdates
 import calendar
 import google_event
+import urllib
 
 from utils import *	
 
@@ -50,7 +51,9 @@ class GoogleConnector:
         self.cal_client = gdata.calendar.service.CalendarService()
         self.cal_client.email = config.get_google_login()
         self.cal_client.password = config.get_google_password()
-        self.cal_client.source = 'Google-Calendar_Python_Sample-1.0'
+        self.cal_client.source = 'Erminig for Maemo'
+        header = self.cal_client.additional_headers['User-Agent']
+        self.gdata_version = header.split("/")[1]
 
         res = (False, None)
         try:
@@ -110,7 +113,6 @@ class GoogleConnector:
         self.googlecalendars = \
             [(x.id.text[63:],x.title.text,x.timezone.value,x.access_level.value) \
                 for x in feed.entry if condition(x)]
-#        printd(self.googlecalendars, True)
         self.isgoogleready = 1
         return 1
         
@@ -190,9 +192,13 @@ class GoogleConnector:
 
     def getevents(self, calendarid, updated_min, updated_max, start_min):
 
-        query = gdata.calendar.service.CalendarEventQuery(calendarid,
-                                                     'private', 'composite',
-                                                     None, {"ctz":"utc"})
+        cid = calendarid
+        if not self.gdata_version.startswith("1.0"):
+            cid = urllib.unquote(calendarid)
+
+        query = gdata.calendar.service.CalendarEventQuery(cid, 'private', 
+                'composite', None, {"ctz":"utc"})
+
         # Adding 1 second to the google update date
         updated_min = \
             datetime.datetime.fromtimestamp(
@@ -247,6 +253,15 @@ class GoogleConnector:
                 the_event['exceptions'].append(
                             exception.entry_link.entry.when[0].start_time)
             the_event['status'] = event.event_status.value
+
+            if event.original_event == None:
+                the_event['single_event'] = True
+            else:
+                the_event['single_event'] = False
+                id = event.original_event.href
+                id = string.replace(id, "%", "#")
+                the_event['id'] =  string.replace(id, "composite", "full")
+            
             the_event['raw'] = event
 
             result_entries.append(the_event)
