@@ -134,7 +134,9 @@ class GpeEvent(dict):
             interval = ";INTERVAL=%s" % (self['rincrement'])
             
         #The exceptions
-        exceptions = string.split(self['rexceptions'], ",")
+        exceptions = []
+        if self['rexceptions']:
+            exceptions = string.split(self['rexceptions'], ",")
         #Sometimes, there is 0 in rexceptions, so I delete it
         print exceptions
         while "0" in exceptions: exceptions.remove("0")
