@@ -421,12 +421,12 @@ class GpeObj:
         
         
     def delete_occurence(self, eventid, occurrence):
-        printd("gpe_service : delete_occurence : entering")
-        printd("gpe_service : delete_occurence : eventid : " + str(eventid))
-        printd("gpe_service : delete_occurence : occurrence : " + str(occurrence))
+        print("gpe_service : delete_occurence : entering")
+        print("gpe_service : delete_occurence : eventid : " + str(eventid))
+        print("gpe_service : delete_occurence : occurrence : " + str(occurrence))
         if 'T' in occurrence : 
             occurrence = str(calendar.timegm(
-                                      time.strptime(occurrence,"%Y%m%dT%H%M%S"))) + ","
+                time.strptime(occurrence,"%Y-%m-%dT%H:%M:%S.000Z"))) + ","
             printd("gpe_service : delete_occurence : occurence : " + str(occurrence))
         else:
             occurrence = str((int(time.mktime(time.strptime(
