@@ -8,7 +8,6 @@
 # 	"The license is whatever you want."
 
 import inspect, linecache, pydoc, sys, traceback
-import os
 from cStringIO import StringIO
 from gettext import gettext as _
 
@@ -16,6 +15,11 @@ import pygtk
 pygtk.require ('2.0')
 import gtk, pango
 
+#def analyse (exctyp, value, tb):
+#	trace = StringIO()
+#	traceback.print_exception (exctyp, value, tb, None, trace)
+#	return trace
+
 def lookup (name, frame, lcls):
 	'''Find the value for a given name in the given frame'''
 	if name in lcls:
@@ -32,47 +36,6 @@ def lookup (name, frame, lcls):
 				return 'builtin', getattr (builtins, name)
 	return None, []
 
-def saveStackTrace(trace):
-	dialog = gtk.FileChooserDialog("Save...", None, gtk.FILE_CHOOSER_ACTION_SAVE,
-			(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_SAVE,
-				gtk.RESPONSE_OK))
-	dialog.set_current_name("erminig_trace.txt")
-	dialog.set_current_folder(os.path.expanduser("~"))
-	loop = True
-	while loop:
-		resp = dialog.run()
-		if resp == gtk.RESPONSE_OK:
-			filename = dialog.get_filename()
-			# check file existence:
-			if os.path.exists(filename):
-				dlg = gtk.MessageDialog(dialog, 0, gtk.MESSAGE_QUESTION,
-						gtk.BUTTONS_YES_NO, "File already exist. Overwrite?")
-				overwriteResponse = dlg.run()
-				dlg.destroy()
-				if overwriteResponse == gtk.RESPONSE_NO:
-					continue
-
-			# Check if file can be written:
-				
-			# Save trace to file:
-			try:
-				f = open(filename, 'w')
-				f.write(trace)
-				f.write("\n")
-				f.close()
-				dialog.destroy()
-				loop = False
-			except IOError:
-				dlg = gtk.MessageDialog(dialog, 0, gtk.MESSAGE_ERROR,
-						gtk.BUTTONS_OK, "Error: could not write to file (check permissions?)")
-				dlg.run()
-				dlg.destroy()
-				continue
-
-		elif resp == gtk.RESPONSE_CANCEL:
-			dialog.destroy()
-			loop = False
-
 def analyse (exctyp, value, tb):
 	import tokenize, keyword
 
@@ -162,7 +125,6 @@ def _info (exctyp, value, tb):
 			  (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE, ))
 			details.set_property ("has-separator", False)
 
-			details.add_button("Save to file...", 3)
 			textview = gtk.TextView(); textview.show()
 			textview.set_editable (False)
 			textview.modify_font (pango.FontDescription ("Monospace"))
@@ -185,10 +147,7 @@ def _info (exctyp, value, tb):
 				h = area.height / 1.6
 			details.set_default_size (int (w), int (h))
 
-			detResp = details.run()
-			if detResp != gtk.RESPONSE_CLOSE:
-				saveStackTrace(trace.getvalue())
-
+			details.run()
 			details.destroy()
 
 		elif resp == 1 and gtk.main_level() > 0:
@@ -200,3 +159,14 @@ def _info (exctyp, value, tb):
 	dialog.destroy()
 
 sys.excepthook = _info
+
+if __name__ == '__main__':
+	class X (object):
+		pass
+	x = X()
+	x.y = 'Test'
+	x.z = x
+	w = ' e'
+	1, x.z.y, f, w
+	raise Exception (x.z.y + w)
+
