@@ -34,7 +34,14 @@ class ProcessEventsObj:
         self.profile_googleupdate = profile['googleupdate']
         self.profile_startdate = profile['startdate']
         self.profile_accesslevel = profile['accesslevel']
-                                    
+
+    def reset_progressbar(self):
+        if (self.progressbar != None):
+            self.current_count = 0;
+            self.progressbar.set_fraction(0.0)
+	    while gtk.events_pending():
+                gtk.main_iteration(False)
+
     def update_progressbar(self):
 	if (self.progressbar != None):
 	        self.current_count = self.current_count + 1
@@ -58,7 +65,7 @@ class ProcessEventsObj:
     def updateall(self, profile_name, parentwindow=None, 
                              progressbar=None, textMode=False, 
                              alwaysDelete=False):
-    
+
         self.init_Profile(profile_name) 
         self.textMode = textMode
         self.progressbar = progressbar
@@ -121,6 +128,8 @@ class ProcessEventsObj:
                 self.set_progressbar_text(self.profile_name + 
                         " : Processing new GPE events")
                 self.ProcessNewEvents()
+
+                self.reset_progressbar()
                                             
         last_google_update = self.ImportGoogleEvents(self.profile_googleupdate, 
                 now_timestamp + timedelta, self.profile_startdate)
@@ -129,6 +138,7 @@ class ProcessEventsObj:
         self.currentcfg.update_lastupdate(self.profile_name,
                                           last_gpe_update,
                                           last_google_update)
+
             
         return 0
     
@@ -144,8 +154,7 @@ class ProcessEventsObj:
         for event in gpe_deleted_events:
             self.update_progressbar()
             self.google_access.delete_event(string.replace(event, "#", "%"))
-            if not self.gpe_access.delete_deletedevent(event):
-                self.reportError("Warning: error during event deletion...")
+            self.gpe_access.delete_deletedevent(event)
             
 
     def ProcessUpdatedEvents(self):
@@ -249,19 +258,15 @@ class ProcessEventsObj:
                     gtk.main_iteration(False)
                 self.AddGPEEvent(event)
             elif (event['status'] == "CANCELED"):     
-                # detect if it's a deleted occurence or a full event to be
-                # deleted.
-                splitted_id = event['id'].split('/')
-                short_id = splitted_id[len(splitted_id) - 1]
-                if short_id.count("_") > 0:
-                    printd("processevents.ImportGoogleEvents : It's a deleted" +\
-                                  " occurrence : " + str(event['id']))
-                    self.gpe_access.delete_occurence(
-                                    event['id'].split("_")[0],
-                                    event['id'].split("_")[1][0:15])
-                else:
-                    printd("processevent.ImportGoogleEvents : it's a canceled event")
+                if event['single_event']:
+                    print("processevent.ImportGoogleEvents : it's a canceled event")
                     self.DeleteGPEEvent(event['id'])
+                else:
+                    self.gpe_access.delete_occurence(event['id'], 
+                                        event['start_date'])
+                    print("processevents.ImportGoogleEvents : It's a deleted" +\
+                                  " occurrence : " + str(event['id']))
+
         printd("processevent.ImportGoogleEvents : Exiting processevents.ImportGoogleEvents()")
         
         return last_update
